@@ -559,8 +559,7 @@ check_inputs_sim_fun <- function(n, lcovars, outcome_betas, surv_dist,
 }
 
 ## for adjusted_rmst function
-check_inputs_adj_rmst <- function(adjsurv, from, to, conf_int, difference,
-                                  ratio) {
+check_inputs_adj_rmst <- function(adjsurv, from, to, conf_int, contrast) {
 
   if ((!is.numeric(from) | !is.numeric(to)) &
       length(from)==1 & length(to)>=1) {
@@ -574,32 +573,29 @@ check_inputs_adj_rmst <- function(adjsurv, from, to, conf_int, difference,
     stop("'from' must be smaller than 'to'.")
   } else if (!(is.logical(conf_int) & length(conf_int)==1)) {
     stop("'conf_int' must be either TRUE or FALSE.")
-  } else if (conf_int & is.null(adjsurv$boot_adjsurv)) {
+  } else if (!(length(contrast)==1 && is.character(contrast) &&
+               contrast %in% c("none", "diff", "ratio"))) {
+    stop("'contrast' must be one of c('none', 'diff', 'ratio').")
+  } else if (conf_int & is.null(adjsurv$boot_adj)) {
     warning("Cannot use bootstrapped estimates because",
             " they were not estimated.",
             " Need 'bootstrap=TRUE' in 'adjustedsurv' function call.",
             call.=FALSE)
   }
 
-  if (any(to > max(adjsurv$adjsurv$time, na.rm=TRUE))) {
+  if (any(to > max(adjsurv$adj$time, na.rm=TRUE))) {
     stop("'to' cannot be greater than the latest observed time.")
   }
 
-  if (length(unique((adjsurv$adjsurv$time))) < 10) {
+  if (length(unique((adjsurv$adj$time))) < 10) {
     warning("Using only a few points in time might lead to biased",
             " estimates. Consider using a finer times grid in",
-            " 'adjustedsurv'.", call.=FALSE)
-  }
-
-  if (difference & ratio) {
-    warning("Cannot calculate the difference and the ratio simultaneously.",
-            " Only the difference will be displayed. To obtain the ratio",
-            " instead, set difference=FALSE.")
+            " 'adjustedsurv' or 'adjustedcif'.", call.=FALSE)
   }
 }
 
 ## for adjusted_rmtl function
-check_inputs_adj_rmtl <- function(adj, from, to, conf_int, difference, ratio) {
+check_inputs_adj_rmtl <- function(adj, from, to, conf_int, contrast) {
 
   if ((!is.numeric(from) | !is.numeric(to)) &
        length(from)==1 & length(to)>=1) {
@@ -614,20 +610,18 @@ check_inputs_adj_rmtl <- function(adj, from, to, conf_int, difference, ratio) {
     stop("'from' must be smaller than 'to'.")
   } else if (!(is.logical(conf_int) & length(conf_int)==1)) {
     stop("'conf_int' must be either TRUE or FALSE.")
-  } else if (conf_int & is.null(adj$boot_adjsurv) & is.null(adj$boot_adjcif)) {
+  } else if (!(length(contrast)==1 && is.character(contrast) &&
+               contrast %in% c("none", "diff", "ratio"))) {
+    stop("'contrast' must be one of c('none', 'diff', 'ratio').")
+  } else if (conf_int & is.null(adj$boot_adj)) {
     warning("Cannot use bootstrapped estimates because",
             " they were not estimated.",
             " Need 'bootstrap=TRUE' in 'adjustedsurv'/'adjustedcif'",
             " function call.", call.=FALSE)
   }
 
-  if (inherits(adj, "adjustedsurv")) {
-    max_t <- max(adj$adjsurv$time, na.rm=TRUE)
-    n_t <- length(unique((adj$adjsurv$time)))
-  } else {
-    max_t <- max(adj$adjcif$time, na.rm=TRUE)
-    n_t <- length(unique((adj$adjcif$time)))
-  }
+  max_t <- max(adj$adj$time, na.rm=TRUE)
+  n_t <- length(unique((adj$adj$time)))
 
   if (any(to > max_t)) {
     stop("'to' cannot be greater than the latest observed time.")
@@ -638,12 +632,6 @@ check_inputs_adj_rmtl <- function(adj, from, to, conf_int, difference, ratio) {
             " estimates. Consider using a finer times grid in",
             " 'adjustedsurv'/'adjustedcif'.", call.=FALSE)
   }
-
-  if (difference & ratio) {
-    warning("Cannot calculate the difference and the ratio simultaneously.",
-            " Only the difference will be displayed. To obtain the ratio",
-            " instead, set difference=FALSE.")
-  }
 }
 
 ## for adjustedsurv_test
@@ -666,28 +654,14 @@ check_inputs_adj_test <- function(adj, from, to) {
     stop("'to' must be greater than 'from'.")
   }
 
-  if (inherits(adj, "adjustedsurv")) {
-    if (to > max(adj$adjsurv$time, na.rm=TRUE)) {
-      stop("'to' cannot be greater than the latest observed time.")
-    }
-  } else {
-    if (to > max(adj$adjcif$time, na.rm=TRUE)) {
-      stop("'to' cannot be greater than the latest observed time.")
-    }
+  if (to > max(adj$adj$time, na.rm=TRUE)) {
+    stop("'to' cannot be greater than the latest observed time.")
   }
 
-  if (inherits(adj, "adjustedsurv")) {
-    if (length(unique((adj$adjsurv$time))) < 10) {
-      warning("Using only a few points in time might lead to biased",
-              " estimates. Consider using a finer times grid in",
-              " 'adjustedsurv'.", call.=FALSE)
-    }
-  } else {
-    if (length(unique((adj$adjcif$time))) < 10) {
-      warning("Using only a few points in time might lead to biased",
-              " estimates. Consider using a finer times grid in",
-              " 'adjustedcif'.", call.=FALSE)
-    }
+  if (length(unique((adj$adj$time))) < 10) {
+    warning("Using only a few points in time might lead to biased",
+            " estimates. Consider using a finer times grid in",
+            " 'adjustedsurv' or 'adjustedcif'.", call.=FALSE)
   }
 }
 
@@ -1084,21 +1058,20 @@ check_inputs_plot_difference <- function(x, group_1, group_2, conf_int,
   } else if (p_value & is.null(test) & is.null(integral_to)) {
     stop("If 'p_value' is specified, either 'test' or 'integral_to' also",
          " need to be specified. See details.")
-  } else if (p_value & is.null(test) & is.null(x$boot_adjsurv) &
-             is.null(x$boot_adjcif)) {
+  } else if (p_value & is.null(test) & is.null(x$boot_adj)) {
     stop("'p_value' can only be used when bootstrap=TRUE was used in the",
          " original adjustedsurv or adjustedcif function call.")
-  } else if (use_boot & is.null(x$boot_adjsurv) & is.null(x$boot_adjcif)) {
+  } else if (use_boot & is.null(x$boot_adj)) {
     stop("Bootstrapped estimates can only be calculated if 'bootstrap=TRUE'",
          " was used in the original adjustedsurv or adjustedcif function",
          " call.")
   } else if (conf_int & !use_boot) {
-    if (inherits(x, "adjustedcif") && !"ci_lower" %in% colnames(x$adjcif)) {
+    if (inherits(x, "adjustedcif") && !"ci_lower" %in% colnames(x$adj)) {
       stop("There are no approximate standard error calculations to use.",
            " Either set 'use_boot=TRUE' or rerun the adjustedcif function",
            " with 'conf_int=TRUE' if possible.")
     } else if (inherits(x, "adjustedsurv") &&
-               !"ci_lower" %in% colnames(x$adjsurv)) {
+               !"ci_lower" %in% colnames(x$adj)) {
       stop("There are no approximate standard error calculations to use.",
            " Either set 'use_boot=TRUE' or rerun the adjustedsurv function",
            " with 'conf_int=TRUE' if possible.")
@@ -1121,41 +1094,27 @@ check_inputs_adj_diff <- function(adj, group_1, group_2, conf_int, use_boot) {
                is.null(group_2))) {
     stop("'group_2' has to be a single character vector, specifying one",
          " of the treatment groups in 'variable'.")
-  } else if (inherits(adj, "adjustedsurv") && !is.null(group_1) &&
-             !group_1 %in% levels(adj$adjsurv$group)) {
+  } else if (!is.null(group_1) && !group_1 %in% levels(adj$adj$group)) {
     stop(group_1, " is not a valid group in 'variable'.")
-  } else if (inherits(adj, "adjustedcif") && !is.null(group_1) &&
-             !group_1 %in% levels(adj$adjcif$group)) {
-    stop(group_1, " is not a valid group in 'variable'.")
-  } else if (inherits(adj, "adjustedsurv") && !is.null(group_1) &&
-             !group_2 %in% levels(adj$adjsurv$group)) {
-    stop(group_2, " is not a valid group in 'variable'.")
-  } else if (inherits(adj, "adjustedcif") && !is.null(group_1) &&
-             !group_2 %in% levels(adj$adjcif$group)) {
+  } else if (!is.null(group_1) && !group_2 %in% levels(adj$adj$group)) {
     stop(group_2, " is not a valid group in 'variable'.")
   } else if (!is.null(group_1) && !is.null(group_2) && group_1 == group_2) {
     stop("'group_1' and 'group_2' may not be equal.")
-  } else if (use_boot & is.null(adj$boot_adjsurv) & is.null(adj$boot_adjcif)) {
+  } else if (use_boot & is.null(adj$boot_adj)) {
     stop("Bootstrapped estimates can only be calculated if 'bootstrap=TRUE'",
          " was used in the original adjustedsurv or adjustedcif function",
          " call.")
-  } else if (conf_int & !use_boot) {
-    if (inherits(adj, "adjustedcif") && !"ci_lower" %in% colnames(adj$adjcif)) {
-      stop("There are no approximate standard error calculations to use.",
-           " Either set 'use_boot=TRUE' or rerun the adjustedcif function",
-           " with 'conf_int=TRUE' if possible.")
-    } else if (inherits(adj, "adjustedsurv") &&
-               !"ci_lower" %in% colnames(adj$adjsurv)) {
-      stop("There are no approximate standard error calculations to use.",
-           " Either set 'use_boot=TRUE' or rerun the adjustedsurv function",
-           " with 'conf_int=TRUE' if possible.")
-    }
+  } else if (conf_int & !use_boot && !"ci_lower" %in% colnames(adj$adj)) {
+    stop("There are no approximate standard error calculations to use.",
+         " Either set 'use_boot=TRUE' or rerun the adjustedsurv/adjustedcif",
+         " function with 'conf_int=TRUE' if possible.")
   }
 }
 
 ## check inputs for adjusted_surv_quantile function
 check_inputs_surv_q <- function(adjsurv, p, conf_int, use_boot,
-                                interpolation) {
+                                interpolation, contrast,
+                                conf_level, group_1, group_2) {
   if (!inherits(adjsurv, "adjustedsurv")) {
     stop("'adjsurv' must be an adjustedsurv object created using the",
          " adjustedsurv function.")
@@ -1163,11 +1122,12 @@ check_inputs_surv_q <- function(adjsurv, p, conf_int, use_boot,
     stop("'p' must be a vector or single number containing only",
          " numbers <= 1 & >= 0.")
   } else if (conf_int && !use_boot &&
-             !"ci_lower" %in% colnames(adjsurv$adjsurv)) {
+             !"ci_lower" %in% colnames(adjsurv$adj) &&
+             !contrast %in% c("diff", "ratio")) {
     stop("There are no approximate confidence intervals to use.",
          " Either set 'use_boot=TRUE' or rerun the adjustedsurv function",
          " with 'conf_int=TRUE' if possible.")
-  } else if (conf_int & use_boot & is.null(adjsurv$boot_adjsurv)) {
+  } else if (conf_int & use_boot & is.null(adjsurv$boot_adj)) {
     stop("Bootstrapped estimates can only be calculated if 'bootstrap=TRUE'",
          " was used in the original adjustedsurv or adjustedcif function",
          " call.")
@@ -1175,12 +1135,38 @@ check_inputs_surv_q <- function(adjsurv, p, conf_int, use_boot,
                interpolation=="steps" | interpolation=="linear")) {
     stop("'interpolation' must be single character string in",
          " c('steps', 'linear').")
+  } else if (!(length(conf_level)==1 && is.numeric(conf_level) &&
+               conf_level < 1 && conf_level > 0)) {
+    stop("'conf_level' must be a single number < 1 and > 0.")
+  } else if (!(length(contrast)==1 && is.character(contrast) &&
+               contrast %in% c("diff", "ratio", "none"))) {
+    stop("'contrast' must be one of c('none', 'diff', 'ratio').")
+  } else if (!(is.null(group_1) || (length(group_1)==1 &&
+               is.character(group_1) &&
+               group_1 %in% levels(adjsurv$adj$group)))) {
+    stop("'group_1' must be a single character string specifying a level",
+         " of the 'variable' column.")
+  } else if (!(is.null(group_2) || (length(group_2)==1 &&
+               is.character(group_2) &&
+               group_2 %in% levels(adjsurv$adj$group)))) {
+    stop("'group_2' must be a single character string specifying a level",
+         " of the 'variable' column.")
+  }
+
+  if (contrast %in% c("diff", "ratio") && conf_int &&
+      ((is.null(adjsurv$mids_analyses) && is.null(adjsurv$boot_data)) ||
+       (!is.null(adjsurv$mids_analyses) &&
+        is.null(adjsurv$mids_analyses[[1]]$boot_data)))) {
+    stop("Cannot calculate confidence intervals for differences/ratios if",
+         " bootstrapping was not performed in the original adjustedsurv()",
+         " function call. Run adjustedsurv() again with bootstrap=TRUE",
+         " to continue.")
   }
 }
 
 ## check inputs for plot_rmst_curve and plot_rmtl_curve
-check_inputs_auc_curve <- function(times=times, max_t=max_t, color=color,
-                                   linetype=linetype, facet=facet) {
+check_inputs_auc_curve <- function(times, max_t, color,
+                                   linetype, facet) {
 
   if (!(length(times)>0 && is.numeric(times) && all(times > 0) |
         is.null(times))) {
@@ -1198,3 +1184,52 @@ check_inputs_auc_curve <- function(times=times, max_t=max_t, color=color,
     stop("'facet' must be either TRUE or FALSE.")
   }
 }
+
+## check inputs for plot_rmst_curve and plot_rmtl_curve
+check_inputs_auc_diff <- function(times, max_t, color, contrast,
+                                  linetype, line_at_ref) {
+
+  if (!(length(times)>0 && is.numeric(times) && all(times > 0) |
+        is.null(times))) {
+    stop("'times' must be a numeric vector containing only values > 0 or NULL.")
+  } else if (!(length(max_t)==1 && (is.infinite(max_t) | is.numeric(max_t)) &&
+               max_t > 0)) {
+    stop("'max_t' must be a single number > 0.")
+  } else if (!(is.character(color) && length(color)==1)) {
+    stop("'color' must be a single character string when using",
+         " difference=TRUE or ratio=TRUE")
+  } else if (!(is.character(linetype) && length(linetype)==1)) {
+    stop("'linetype' must be a single character string when using",
+         " difference=TRUE or ratio=TRUE")
+  } else if (!(is.logical(line_at_ref) && length(line_at_ref)==1)) {
+    stop("'line_at_ref' must be either TRUE or FALSE.")
+  } else if (!(length(contrast)==1 && is.character(contrast) &&
+               contrast %in% c("none", "diff", "ratio"))) {
+    stop("'contrast' must be one of c('none', 'diff', 'ratio').")
+  }
+}
+
+## input checks when using risk tavles in plot.adjustedsurv()
+check_inputs_risk_table <- function(method, type, use_weights, stratify, warn) {
+
+  # errors
+  if (!type %in% c("n_at_risk", "n_cens", "n_events")) {
+    stop("'risk_table_type' must be either 'n_at_risk', 'n_cens' or",
+         " 'n_events'.")
+  }
+
+  # (optional) warnings
+  if (!method %in% c("km", "iptw_km", "iptw_cox") && stratify && warn) {
+    warning("Adding stratified risk tables may produce confusing output when",
+            " using methods other then 'km', 'iptw_km' or 'iptw_cox',",
+            " because all other methods do not use risk tables to estimate",
+            " the survival curves. See details. Set risk_table_warn=FALSE",
+            " to silence this warning.")
+  }
+  if (method %in% c("iptw_km", "iptw_cox", "iptw_pseudo") &&
+      !use_weights && warn) {
+    warning("Unweighted risk tables were added to plots created with",
+            " weighted data. This may lead to confusing output. See",
+            " details. Set risk_table_warn=FALSE to silence this warning.")
+  }
+}
