@@ -15,6 +15,7 @@ adj <- adjustedsurv(data=sim_dat,
                     conf_int=TRUE,
                     bootstrap=FALSE)
 
+# competing risks case
 sim_dat$event[1] <- 2
 adjcif <- adjustedcif(data=sim_dat,
                       variable="group",
@@ -39,9 +40,24 @@ test_that("surv, times", {
   expect_equal(round(adj_diff$diff[1], 4), -0.2425)
 })
 
+test_that("surv, times, conf_int", {
+  adj_diff <- adjusted_curve_diff(adj, times=0.8, conf_int=TRUE)
+  expect_equal(nrow(adj_diff), 1)
+  expect_equal(round(adj_diff$diff[1], 4), -0.2425)
+  expect_equal(round(adj_diff$se[1], 4), 0.2603)
+  expect_equal(round(adj_diff$ci_lower[1], 3), -0.753)
+})
+
 test_that("cif, times", {
+  adj_diff <- adjusted_curve_diff(adjcif, times=0.8)
+  expect_equal(nrow(adj_diff), 1)
+  expect_equal(round(adj_diff$diff[1], 4), 0.2343)
+})
+
+test_that("cif, times, conf_int", {
   adj_diff <- adjusted_curve_diff(adjcif, times=0.8, conf_int=TRUE,
                                   use_boot=TRUE)
   expect_equal(nrow(adj_diff), 1)
   expect_equal(round(adj_diff$diff[1], 4), 0.2343)
+  expect_equal(round(adj_diff$se[1], 4), 0.0228)
 })
